#!/usr/bin/perl -w
#
# $Id: makeplot.pl,v 1.1 2001/03/22 07:18:36 kjc Exp kjc $
#
#  usage:
#	makeplot.pl <plotdatafile> [<pngfile>]
#
#  example: to create a plot graph, sample.png
#	aguri -P -yK -xd agr_files     > plotdata
#	makeplot.pl plotdata | gnuplot > sample.png
#
umask(002);
$pngfile = "";

if ($#ARGV < 0)  { die "plotdata file not specified!"; }
$datafile   = $ARGV[0];
if ($#ARGV > 0) {
    $pngfile = $ARGV[1];
}

sub putpreamble {
    print <<EOF
set terminal png color small
set key below Left
set xlabel "Time"
set ylabel "Traffic (Kbps)"
#set yrange [0:10000]	# to fix y-scale
set xdata time
set timefmt "%Y/%m/%d:%H:%M:%S"
set format x "%H:%M:%S\\n%m/%d"
set timefmt "%Y/%m/%d:%H:%M:%S"
EOF
}

open(DATA, "< $datafile") || die $!;
while(<DATA>) {
    # detect type
    if (/^#\[(.*)\]/) {
	$title = $1;
	next;
    }
    # read names for legends, and then, output gnuplot command
    if (/^#time/) {
	chop;
	@legends = split;
	$entries = $#legends + 1;
	print "set title \'$title\'\n";
	if ($pngfile ne "") {
	    print "set output \"$pngfile\"\n";
	}
	putpreamble();
	for ($i = 1; $i < $entries; $i++) {
	    if ($i == 1) {
		print "plot ";
	    } else {
		print ", ";
	    }
	    print "\"$datafile\" using 1:", $i+1, " t \'$legends[$i]\' w lines";
	}
	print "\n";
	last;
    }
}
close(DATA);
exit 0;
